@@ -7,7 +7,7 @@ import hildon
 from os import listdir, path, system
 from ConfigParser import SafeConfigParser
 
-version = "1.6-5"
+version = "1.6-6"
 trackingEnabled = True
 stopTracking = True
 stopWhenIdle = False
@@ -189,9 +189,9 @@ class Main(object):
         self.main()
     
     def main(self):
-        window = hildon.Window()
-        window.set_title("OpenSSH Status Widget")
-        window.connect("delete_event", gtk.main_quit, None)
+        self.window = hildon.Window()
+        self.window.set_title("OpenSSH Status Widget")
+        self.window.connect("delete_event", gtk.main_quit, None)
         
         self.labelWidget = gtk.Label("Widget options:")
         self.labelServer = gtk.Label("Server options:")
@@ -279,7 +279,7 @@ class Main(object):
         
         vboxBorder.pack_start(areaScrolling, True, True, 0)
         
-        window.add(vboxBorder)
+        self.window.add(vboxBorder)
         
         if stopTracking:
             self.buttonStopTracking.set_active(True)
@@ -360,9 +360,9 @@ class Main(object):
         self.buttonWifiPMOnSec.connect("value-changed", self.buttonWifiPMOnSec_changed)
         
         menu = self.create_menu()
-        window.set_app_menu(menu)
+        self.window.set_app_menu(menu)
         
-        window.show_all()
+        self.window.show_all()
     
         gtk.main()
         
@@ -595,12 +595,12 @@ class Main(object):
         self.write_config()
     
     def about_clicked(self, dummy):
-        self.about = gtk.Dialog("Info", None)
+        self.about = gtk.Dialog("Info", self.window)
         logo = gtk.image_new_from_file("/usr/share/icons/hicolor/64x64/apps/openssh-status.png")
         textApp = gtk.Label("<big><b>OpenSSH Status Widget  "+version+"</b></big>")
         textApp.set_use_markup(True)
         textApp.set_line_wrap(True)
-        textIandI = gtk.Label("Created by Marc Poepperl (rasmarc)\n")
+        textIandI = gtk.Label("Created by Marc P"+"\xc3\xb6".decode('utf-8')+"pperl (rasmarc)\n")
         buttonForum = hildon.Button(gtk.HILDON_SIZE_FULLSCREEN_WIDTH | gtk.HILDON_SIZE_FINGER_HEIGHT, hildon.BUTTON_ARRANGEMENT_HORIZONTAL | hildon.BUTTON_STYLE_NORMAL)
         buttonForum.set_label('Go to forum thread')
         vbox2 = gtk.VBox(False,16)
