@@ -14,7 +14,7 @@ from ConfigParser import SafeConfigParser
 try:
     remove("/home/user/.openssh-status-connected")
 except:
-    print("")
+    pass
 
 class opensshStatus(hildondesktop.StatusMenuItem):
     def __init__(self):
@@ -231,6 +231,10 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             if self.sshRunning and not self.on:
                 self.on = True
                 self.button.set_image(self.image_on)
+                if self.sshConnected == 1:
+                    self.button.set_text("OpenSSH Server", "1 connection")
+                else:
+                    self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connections")
                 if self.sshConnected and self.showConnected:
                     self.connected = True
                     self.set_status_area_icon(self.icon_plus)
@@ -250,7 +254,7 @@ class opensshStatus(hildondesktop.StatusMenuItem):
                 self.labelConnected = self.sshConnected
                 self.waitWhileIdle = False
                 if self.sshConnected == 1:
-                    self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connection")
+                    self.button.set_text("OpenSSH Server", "1 connection")
                     return True
                 elif self.sshConnected > 1 or (not self.sshConnected and self.sshRunning):
                     self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connections")
@@ -325,19 +329,14 @@ class opensshStatus(hildondesktop.StatusMenuItem):
             self.button.set_image(self.image_on)
             if self.trackingEnabled:
                 self.sshUsers()
-                if self.sshConnected:
-                    if self.sshConnected == 1:
-                        self.button.set_text("OpenSSH Server", "1 connection")
-                    else:
-                        self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connections")
-                    if self.showConnected:
-                        self.connected = True
-                        self.set_status_area_icon(self.icon_plus)
-                    else:
-                        self.connected = False
-                        self.set_status_area_icon(self.icon)
+                if self.sshConnected == 1:
+                    self.button.set_text("OpenSSH Server", "1 connection")
+                else:
+                    self.button.set_text("OpenSSH Server", str(self.sshConnected)+" connections")
+                if self.sshConnected and showConnected:
+                    self.connected = True
+                    self.set_status_area_icon(self.icon_plus)
                 else:
-                    self.button.set_text("OpenSSH Server", "0 connections")
                     self.connected = False
                     self.set_status_area_icon(self.icon)
                 if not self.refresh:
